#include <Arduino.h>
#include <pcf8574_esp.h>
#include <PolledTimeout.h>

#define PCF_INT_PIN D5
#define PCF_DEBOUNCE_MS 50
#define PCF_INPUT1 3
#define PCF_INPUT2 2
#define PCF_INPUT3 1
#define PCF_INPUT4 0

PCF857x pcf8574(0x20, &Wire);
esp8266::polledTimeout::oneShotFastMs pcfInterruptDebounced(PCF_DEBOUNCE_MS);

volatile bool PcfInterruptDetected = false;
void ICACHE_RAM_ATTR PcfInterruptRoutine()
{
	PcfInterruptDetected = true;
}

void setup()
{
	Serial.begin(9600);
	Wire.begin();
	Wire.setClock(100000L);
	pcf8574.begin();
	pcf8574.resetInterruptPin();
	attachInterrupt(digitalPinToInterrupt(PCF_INT_PIN), PcfInterruptRoutine, FALLING);

	Serial.println("Setup ready");
}

void loop()
{
	if (PcfInterruptDetected)
	{
		Serial.println(F("PcfInterrrupt occurred"));

		if (pcfInterruptDebounced)
		{
			Serial.println(F("PcfInterrupt debounced"));

			if (pcf8574.read(PCF_INPUT1) == 1)
				Serial.println("Pin PCF_INPUT1 is HIGH!");
			else
				Serial.println("Pin PCF_INPUT1 is LOW!");

			if (pcf8574.read(PCF_INPUT2) == 1)
				Serial.println("Pin PCF_INPUT2 is HIGH!");
			else
				Serial.println("Pin PCF_INPUT2 is LOW!");

			if (pcf8574.read(PCF_INPUT3) == 1)
				Serial.println("Pin PCF_INPUT3 is HIGH!");
			else
				Serial.println("Pin PCF_INPUT3 is LOW!");

			if (pcf8574.read(PCF_INPUT4) == 1)
				Serial.println("Pin PCF_INPUT4 is HIGH!");
			else
				Serial.println("Pin PCF_INPUT4 is LOW!");

			PcfInterruptDetected = false;
		}
		pcfInterruptDebounced.reset();
	}
}